@@ -1,6 +1,4 @@
-use super::Arbitrary;
 use ark_ff::fields::PrimeField;
-use ark_std::marker::PhantomData;
 
 #[cfg(feature = "r1cs")]
 pub mod constraints;
@@ -25,11 +23,3 @@ impl<F: PrimeField> Input<F> {
 		}
 	}
 }
-
-pub struct BridgeData<F: PrimeField> {
-	field: PhantomData<F>,
-}
-
-impl<F: PrimeField> Arbitrary for BridgeData<F> {
-	type Input = Input<F>;
-}
